@@ -41,6 +41,11 @@ class _WiserSmartPlug(_WiserDevice):
         self._name = device_type_data.get("Name", TEXT_UNKNOWN)
         self._device_lock_enabled = data.get("DeviceLockEnabled", False)
         self._output_state = device_type_data.get("OutputState", TEXT_OFF)
+        self._indentify_active = data.get("IdentifyActive", False)
+
+        # Add device id to schedule
+        if self._schedule:
+            self.schedule._device_ids.append(self.id)
 
     def _send_command(self, cmd: dict, device_level: bool = False):
         """
@@ -113,6 +118,16 @@ class _WiserSmartPlug(_WiserDevice):
         if self._send_command({"DeviceLockEnabled": enable}, True):
             self._device_lock_enabled = enable
 
+    @property
+    def identify(self) -> bool:
+        """Get or set if the smartplug identify function is enabled"""
+        return self._indentify_active
+
+    @identify.setter
+    def identify(self, enable: bool = False):
+        if self._send_command({"Identify": enable}, True):
+            self._indentify_active = enable
+
     @property
     def instantaneous_power(self) -> int:
         """Get the amount of current throught the plug now"""
